AgentProviderException class

Thrown when a provider's HTTP request fails.

Implemented types
Annotations

Constructors

AgentProviderException(int statusCode, String body)
Creates an exception for a failed provider request.
const

Properties

body String
The raw response body, for diagnostics.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
The HTTP status code returned.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited